@@ -9,7 +9,7 @@ var languageNames = {
 "bs": "Bosnia",
 "bg": "Bulgaria",
 "ca": "Katalan",
-"ca-valencia": "Catalan (Valencia)",
+"ca-valencia": "Katalan (Valencia)",
 "zh-CN": "Cina (Disederhanakan)",
 "zh-TW": "Cina (Tradisional)",
 "hr": "Kroasia",
@@ -48,15 +48,15 @@ var languageNames = {
 "om": "Etiopia",
 "pl": "Polandia",
 "pt": "Portugis",
-"pt-BR": "Portuguese (Brazil)",
+"pt-BR": "Portugis (Brasil)",
 "ro": "Romania",
 "ru": "Rusia",
 "sid": "Sidama",
 "si": "Sri Lanka",
 "sk": "Slowakia",
 "sl": "Slovenia",
-"dsb": "Sorbian (Lower)",
-"hsb": "Sorbian (Upper)",
+"dsb": "Sorbia (Hilir)",
+"dsb": "Sorbia (Hulu)",
 "es": "Spanyol",
 "sv": "Swedia",
 "tg": "Tajikistan",
